/***********************************************************************
 *        FILE: dtilib.cpp
 * DESCRIPTION: Cross compatibility Library file for DIALOGIC Windows NT
 *
 *   Copyright (c) 1991-1996 Dialogic Corp. All Rights Reserved
 *
 *   THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF Dialogic Corp.
 *   The copyright notice above does not evidence any actual or
 *   intended publication of such source code.
 **********************************************************************/

#ifndef __CROSS_COMPAT_LIB__
#define __CROSS_COMPAT_LIB__
#endif

#include <windows.h>
#include "srllib.h"
#include "dtilib.h"
#include "msilib.h"
#include "dcblib.h"
#include "cclib.h"

//
// function prototypes
//
static void dt_dflt_lasterr(int ddd,long error);
static long dt_long_notimp(int ddd);
static char * dt_null_notimp(int ddd);

//
// typedefs and defines
//
typedef void (*func_ptr)(void);
struct func_table {
	char *fname;
	func_ptr fptr;
};

#define      ATDT_BDSGBIT_ID    0
#define      ATDT_BDMODE_ID     1
#define      ATDT_DNLDVER_ID    2
#define      ATDT_IDLEST_ID     3
#define      ATDT_ROMVER_ID     4
#define      ATDT_STATUS_ID     5
#define      ATDT_TSMODE_ID     6
#define      ATDT_TSSGBIT_ID    7
#define      dt_close_ID        8
#define      dt_dial_ID         9
#define      dt_getctinfo_ID    10
#define      dt_getevtmsk_ID    11
#define      dt_getparm_ID      12
#define      dt_getxmitslot_ID  13
#define      dt_listen_ID       14
#define      dt_mtfcn_ID        15
#define      dt_open_ID         16
#define      dt_rundiag_ID      17
#define      dt_setalrm_ID      18
#define      dt_setevtmsk_ID    19
#define      dt_setidle_ID      20
#define      dt_setparm_ID      21
#define      dt_setsigmod_ID    22
#define      dt_settssig_ID     23
#define      dt_settssigsim_ID  24
#define      dt_tstcom_ID       25
#define      dt_tstdat_ID       26
#define      dt_unlisten_ID     27
#define      dt_xmitalrm_ID     28
#define      dt_xmittone_ID     29
#define      dt_xmitwink_ID     30
#define      dt_route_ID        31
#define      dt_getevt_ID       32
#define      dt_set_lasterr_ID  33
#define      dt_setiostatus_ID  34   

typedef char * (*ptr_ATDT_BDSGBIT)(int);
typedef long  (*ptr_ATDT_BDMODE)(int);
typedef long  (*ptr_ATDT_DNLDVER)(int);
typedef long  (*ptr_ATDT_IDLEST)(int);
typedef long  (*ptr_ATDT_ROMVER)(int);
typedef long  (*ptr_ATDT_STATUS)(int);
typedef long  (*ptr_ATDT_TSMODE)(int);
typedef long  (*ptr_ATDT_TSSGBIT)(int);
typedef int   (*ptr_dt_close)(int);
typedef int   (*ptr_dt_dial)(int, char *, unsigned int);
typedef int   (*ptr_dt_getctinfo)(int, CT_DEVINFO *);
typedef int   (*ptr_dt_getevtmsk)(int, int, unsigned short *);
typedef int   (*ptr_dt_getparm)(int, unsigned long, void *);
typedef int   (*ptr_dt_getxmitslot)(int, SC_TSINFO *);
typedef int   (*ptr_dt_listen)(int, SC_TSINFO *);
typedef int   (*ptr_dt_mtfcn)(int, unsigned char, unsigned int);
typedef int   (*ptr_dt_open)(char *, int);
typedef int   (*ptr_dt_rundiag)(int, unsigned int, char *);
typedef int   (*ptr_dt_setalrm)(int, unsigned int);
typedef int   (*ptr_dt_setevtmsk)(int, int, unsigned short, int);
typedef int   (*ptr_dt_setidle)(int, unsigned int);
typedef int   (*ptr_dt_setparm)(int, unsigned long, void *);
typedef int   (*ptr_dt_setsigmod)(int, unsigned int);
typedef int   (*ptr_dt_settssig)(int, unsigned short, int);
typedef int   (*ptr_dt_settssigsim)(int, unsigned short);
typedef int   (*ptr_dt_tstcom)(int, unsigned int);
typedef int   (*ptr_dt_tstdat)(int, unsigned int);
typedef int   (*ptr_dt_unlisten)(int);
typedef int   (*ptr_dt_xmitalrm)(int, unsigned char, unsigned int);
typedef int   (*ptr_dt_xmittone)(int, unsigned int);
typedef int   (*ptr_dt_xmitwink)(int, unsigned int);
typedef int   (*ptr_dt_route)(int, int, int, int);
typedef int   (*ptr_dt_getevt)(int, EV_EBLK *, int);
typedef void  (*ptr_dt_set_lasterr)(int, int);
typedef int   (*ptr_dt_setiostatus)(int, int);
//
// Global variables
//
static struct func_table DtiFunc[] = {
{ "ATDT_BDSGBIT",            (func_ptr)dt_null_notimp },
{ "ATDT_BDMODE",             (func_ptr)dt_long_notimp },
{ "ATDT_DNLDVER",            (func_ptr)dt_long_notimp },
{ "ATDT_IDLEST",             (func_ptr)dt_long_notimp },
{ "ATDT_ROMVER",             (func_ptr)dt_long_notimp },
{ "ATDT_STATUS",             (func_ptr)dt_long_notimp },
{ "ATDT_TSMODE",             (func_ptr)dt_long_notimp },
{ "ATDT_TSSGBIT",            (func_ptr)dt_long_notimp },
{ "dt_close",                (func_ptr)dt_long_notimp },
{ "dt_dial",                 (func_ptr)dt_long_notimp }, 
{ "dt_getctinfo",            (func_ptr)dt_long_notimp }, 
{ "dt_getevtmsk",            (func_ptr)dt_long_notimp }, 
{ "dt_getparm",              (func_ptr)dt_long_notimp }, 
{ "dt_getxmitslot",          (func_ptr)dt_long_notimp }, 
{ "dt_listen",               (func_ptr)dt_long_notimp }, 
{ "dt_mtfcn",                (func_ptr)dt_long_notimp }, 
{ "dt_open",                 (func_ptr)dt_long_notimp }, 
{ "dt_rundiag",              (func_ptr)dt_long_notimp }, 
{ "dt_setalrm",              (func_ptr)dt_long_notimp }, 
{ "dt_setevtmsk",            (func_ptr)dt_long_notimp }, 
{ "dt_setidle",              (func_ptr)dt_long_notimp }, 
{ "dt_setparm",              (func_ptr)dt_long_notimp }, 
{ "dt_setsigmod",            (func_ptr)dt_long_notimp }, 
{ "dt_settssig",             (func_ptr)dt_long_notimp }, 
{ "dt_settssigsim",          (func_ptr)dt_long_notimp }, 
{ "dt_tstcom",               (func_ptr)dt_long_notimp }, 
{ "dt_tstdat",               (func_ptr)dt_long_notimp }, 
{ "dt_unlisten",             (func_ptr)dt_long_notimp }, 
{ "dt_xmitalrm",             (func_ptr)dt_long_notimp }, 
{ "dt_xmittone",             (func_ptr)dt_long_notimp }, 
{ "dt_xmitwink",             (func_ptr)dt_long_notimp }, 
{ "dt_route",                (func_ptr)dt_long_notimp },
{ "dt_getevt",               (func_ptr)dt_long_notimp },
{ "dt_set_lasterr",          (func_ptr)dt_dflt_lasterr},
{ "dt_setiostatus",          (func_ptr)dt_long_notimp }
};

static  char mtlibname[] = "LIBDTIMT.DLL";
static  char stlibname[] = "LIBDTI.DLL";
static  char *libname;


long dt_libinit(unsigned short flag)
{
	struct func_table *dtip = DtiFunc;
	func_ptr ProcAddress;
	static HINSTANCE LibHandle = NULL;
	DWORD filever, prodver;
	DWORD NumberofFunctions;

	//
	// Check if already open
	//
	if (LibHandle != (HINSTANCE)NULL) {
		return -1;
	}

	//
	// Determine thelibrary to load
	//
	if ((flag & DLGC_MT) == DLGC_MT) {
		libname = mtlibname;
	} else {
		libname = mtlibname;
		dt_GetDllVersion(&filever, &prodver);
		if (filever <= 0x0004000A) {
			libname = stlibname;
		}
	}

	NumberofFunctions = sizeof(DtiFunc)/sizeof(DtiFunc[0]);

	//
	// Try and load the DTI library. If no library then setup
	// default entry points for each function
	//
	if ((LibHandle = LoadLibrary(libname)) == (HINSTANCE)NULL) {
		return 0;
	}

	//
	// The library has been loaded. Set up each entry to a default
	// not implemented function and then overwrite the true address if
	// the function is present in the DLL.
	//
	while (NumberofFunctions --) {
		ProcAddress = (func_ptr)GetProcAddress(LibHandle, dtip->fname);
		if (ProcAddress) {
			dtip->fptr = ProcAddress;
		}
		    dtip++;
	}

   /* mlk_fix 980714 - added load of ISDN library */
   cc_libinit(LibHandle);
	ms_libinit(LibHandle);
	dcb_libinit(LibHandle);

	return 0;
}

char * ATDT_BDSGBIT(int devh)
{
	ptr_ATDT_BDSGBIT p;

	p = (ptr_ATDT_BDSGBIT)*DtiFunc[ATDT_BDSGBIT_ID].fptr;
	return (*p)(devh);
}

long ATDT_BDMODE(int devh)
{
	ptr_ATDT_BDMODE p;

	p = (ptr_ATDT_BDMODE)*DtiFunc[ATDT_BDMODE_ID].fptr;
	return (*p)(devh);
}

long ATDT_DNLDVER(int devh)
{
	ptr_ATDT_DNLDVER p;

	p = (ptr_ATDT_DNLDVER)*DtiFunc[ATDT_DNLDVER_ID].fptr;
	return (*p)(devh);
}

long ATDT_IDLEST(int devh)
{
	ptr_ATDT_IDLEST p;

	p = (ptr_ATDT_IDLEST)*DtiFunc[ATDT_IDLEST_ID].fptr;
	return (*p)(devh);
}

long ATDT_ROMVER(int devh)
{
	ptr_ATDT_ROMVER p;

	p = (ptr_ATDT_ROMVER)*DtiFunc[ATDT_ROMVER_ID].fptr;
	return (*p)(devh);
}

long ATDT_STATUS(int devh)
{
	ptr_ATDT_STATUS p;

	p = (ptr_ATDT_STATUS)*DtiFunc[ATDT_STATUS_ID].fptr;
	return (*p)(devh);
}

long ATDT_TSMODE(int devh)
{
	ptr_ATDT_TSMODE p;

	p = (ptr_ATDT_TSMODE)*DtiFunc[ATDT_TSMODE_ID].fptr;
	return (*p)(devh);
}

long ATDT_TSSGBIT(int devh)
{
	ptr_ATDT_TSSGBIT p;

	p = (ptr_ATDT_TSSGBIT)*DtiFunc[ATDT_TSSGBIT_ID].fptr;
	return (*p)(devh);
}

int  dt_close(int devh)
{
	ptr_dt_close p;

	p = (ptr_dt_close)*DtiFunc[dt_close_ID].fptr;
	return (*p)(devh);
}

int  dt_dial(int devh, char * dialstr, unsigned int tmo)
{
	ptr_dt_dial p;

	p = (ptr_dt_dial)*DtiFunc[dt_dial_ID].fptr;
	return (*p)(devh, dialstr, tmo);
}

int  dt_getctinfo(int devh, CT_DEVINFO *devinfop)
{
	ptr_dt_getctinfo p;

	p = (ptr_dt_getctinfo)*DtiFunc[dt_getctinfo_ID].fptr;
	return (*p)(devh, devinfop);
}

int  dt_getevtmsk(int devh, int event, unsigned short * bitmaskp)
{
	ptr_dt_getevtmsk p;

	p = (ptr_dt_getevtmsk)*DtiFunc[dt_getevtmsk_ID].fptr;
	return (*p)(devh, event, bitmaskp);
}

int  dt_getparm(int devh, unsigned long param, void * valuep)
{
	ptr_dt_getparm p;

	p = (ptr_dt_getparm)*DtiFunc[dt_getparm_ID].fptr;
	return (*p)(devh, param, valuep);
}

int  dt_getxmitslot(int devh, SC_TSINFO *tsinfop)
{
	ptr_dt_getxmitslot p;

	p = (ptr_dt_getxmitslot)*DtiFunc[dt_getxmitslot_ID].fptr;
	return (*p)(devh, tsinfop);
}

int  dt_listen(int devh, SC_TSINFO *tsinfop)
{
	ptr_dt_listen p;

	p = (ptr_dt_listen)*DtiFunc[dt_listen_ID].fptr;
	return (*p)(devh, tsinfop);
}

int  dt_mtfcn(int devh, unsigned char fncid, unsigned int tmo)
{
	ptr_dt_mtfcn p;

	p = (ptr_dt_mtfcn)*DtiFunc[dt_mtfcn_ID].fptr;
	return (*p)(devh, fncid, tmo);
}

int  dt_open(char *name, int oflags)
{
	ptr_dt_open p;

	p = (ptr_dt_open)*DtiFunc[dt_open_ID].fptr;
	return (*p)(name, oflags);
}

int  dt_rundiag(int devh, unsigned int tmo, char * diagbufp)
{
	ptr_dt_rundiag p;

	p = (ptr_dt_rundiag)*DtiFunc[dt_rundiag_ID].fptr;
	return (*p)(devh, tmo, diagbufp);
}

int  dt_setalrm(int devh, unsigned int mode)
{
	ptr_dt_setalrm p;

	p = (ptr_dt_setalrm)*DtiFunc[dt_setalrm_ID].fptr;
	return (*p)(devh, mode);
}

int  dt_setevtmsk(int devh, int event, unsigned short bitmask, int action)
{
	ptr_dt_setevtmsk p;

	p = (ptr_dt_setevtmsk)*DtiFunc[dt_setevtmsk_ID].fptr;
	return (*p)(devh, event, bitmask, action);
}

int  dt_setidle(int devh, unsigned int state)
{
	ptr_dt_setidle p;

	p = (ptr_dt_setidle)*DtiFunc[dt_setidle_ID].fptr;
	return (*p)(devh, state);
}

int  dt_setparm(int devh, unsigned long param, void * valuep)
{
	ptr_dt_setparm p;

	p = (ptr_dt_setparm)*DtiFunc[dt_setparm_ID].fptr;
	return (*p)(devh, param, valuep);
}

int  dt_setsigmod(int devh, unsigned int mode)
{
	ptr_dt_setsigmod p;

	p = (ptr_dt_setsigmod)*DtiFunc[dt_setsigmod_ID].fptr;
	return (*p)(devh, mode);
}

int  dt_settssig(int devh, unsigned short bitmask, int action)
{
	ptr_dt_settssig p;

	p = (ptr_dt_settssig)*DtiFunc[dt_settssig_ID].fptr;
	return (*p)(devh, bitmask, action);
}

int  dt_settssigsim(int devh, unsigned short bitmask)
{
	ptr_dt_settssigsim p;

	p = (ptr_dt_settssigsim)*DtiFunc[dt_settssigsim_ID].fptr;
	return (*p)(devh, bitmask);
}

int  dt_tstcom(int devh, unsigned int tmo)
{
	ptr_dt_tstcom p;

	p = (ptr_dt_tstcom)*DtiFunc[dt_tstcom_ID].fptr;
	return (*p)(devh, tmo);
}

int  dt_tstdat(int devh, unsigned int tmo)
{
	ptr_dt_tstdat p;

	p = (ptr_dt_tstdat)*DtiFunc[dt_tstdat_ID].fptr;
	return (*p)(devh, tmo);
}

int  dt_unlisten(int devh)
{
	ptr_dt_unlisten p;

	p = (ptr_dt_unlisten)*DtiFunc[dt_unlisten_ID].fptr;
	return (*p)(devh);
}

int  dt_xmitalrm(int devh, unsigned char alarmtype, unsigned int state)
{
	ptr_dt_xmitalrm p;

	p = (ptr_dt_xmitalrm)*DtiFunc[dt_xmitalrm_ID].fptr;
	return (*p)(devh, alarmtype, state);
}

int  dt_xmittone(int devh, unsigned int state)
{
	ptr_dt_xmittone p;

	p = (ptr_dt_xmittone)*DtiFunc[dt_xmittone_ID].fptr;
	return (*p)(devh, state);
}

int  dt_xmitwink(int devh, unsigned int tmo)
{
	ptr_dt_xmitwink p;

	p = (ptr_dt_xmitwink)*DtiFunc[dt_xmitwink_ID].fptr;
	return (*p)(devh, tmo);
}

int  dt_route(int devh, int chan, int tms, int mode)
{
	ptr_dt_route p;

	p = (ptr_dt_route)*DtiFunc[dt_route_ID].fptr;
	return (*p)(devh, chan, tms, mode);
}

int  dt_getevt(int devh, EV_EBLK * eblkp, int tmo)
{
	ptr_dt_getevt p;

	p = (ptr_dt_getevt)*DtiFunc[dt_getevt_ID].fptr;
	return (*p)(devh, eblkp, tmo);
}

int  dt_setiostatus(int devh, int status)
{
	ptr_dt_setiostatus p;

	p = (ptr_dt_setiostatus)*DtiFunc[dt_setiostatus_ID].fptr;
	return (*p)(devh, status);
}

void  dt_set_lasterr(int devh, int error)
{
	ptr_dt_set_lasterr p;

	p = (ptr_dt_set_lasterr)*DtiFunc[dt_set_lasterr_ID].fptr;
	(*p)(devh, error);
}

#pragma argsused
void dt_dflt_lasterr(int devh, long error)
{
}

long dt_long_notimp(int devh)
{
	dt_set_lasterr(devh, EDT_INVMSG);
	return -1;
}

char *dt_null_notimp(int devh)
{
	dt_set_lasterr(devh,EDT_INVMSG);
	return (char *)NULL;
}

long dt_GetDllVersion( LPDWORD fileverp, LPDWORD prodverp)
{
	return sr_GetVersion(libname,fileverp, prodverp);
}


