/***************************************************************************
 *              Copyright (c) 1996 Dialogic Corp.
 *              All Rights Reserved.
 *
 *              THIS IS UNPUBLISHED PROPRIETARY SOURCE CODE OF Dialogic Corp.
 *              The copyright notice above does not evidence any actual or
 *              intended publication of such source code.
 ***************************************************************************/

/****************************************************************************
 * FILE:         qmsg.h
 * ORG:          Dialogic Corporation
 * ORIG-DATE:    28-Aug-96
 * LAST-MOD:     22-Jul-97
 * PURPOSE:
 *    This file contains defines and structures for the Mercury messages.
 *
 ***************************************************************************/
					     
#ifndef __QMSG_H__         
#define __QMSG_H__          
						   
// Define flag if compiling MNTI host library.
// Undefine flag if compiling applications.
#ifndef __MNTILIB_
#define MNTAPI __declspec(dllimport)
#else
#define MNTAPI __declspec(dllexport)
#endif

// These type definitions are for the local resource message format
typedef UInt8           QBufferType;
typedef UInt24		      QByteOrder;
typedef UInt24 	      QMsgPriority;
typedef UInt24 	      QMsgVersion;
typedef UInt24          QMsgSize;

#define MNT_MAX_VALUE_NAME_SIZE  32
#define MNT_MAX_VALUE_SIZE       64
#define MNT_ANY_ATTR_STRING      "*"

#define MNT_MATCH_ANY_VALUE   0x01

#define NORMAL_MSG FALSE

typedef struct {
	int node;
	int boardNumber;
	int component;
	int instance;
	int processor;
} MERC_ADDR, *PMERC_ADDR;

// structures for function mntGetBoardByAttr
typedef struct {
   char     ValueName[MNT_MAX_VALUE_NAME_SIZE];
   ULONG    ValueType;
   BYTE     ValueFlag;
   char     Value[MNT_MAX_VALUE_SIZE];
} QValueAttr, *PQValueAttr;

typedef struct {
   char     ValueName[MNT_MAX_VALUE_NAME_SIZE];
   ULONG    ValueType;
   char     Value[MNT_MAX_VALUE_SIZE];
   ULONG    BoardNo;
} QBoardAttr, *PQBoardAttr;

// Define handle strings for function mntGetBoardByAttr
#define MNT_STR_HKEY_LOCAL_MACHINE      "HKEY_LOCAL_MACHINE"
#define MNT_STR_SOFTWARE                           "Software"
#define MNT_STR_DIALOGIC                           "Dialogic"
#define MNT_STR_INSTALLED_BOARDS           "Installed Boards"
#define MNT_STR_MERCURY                            "Mercury"
#define MNT_STR_LOGICAL_BOARD_ID           "LogicalID"
#define MNT_STR_PHYSICAL_ATTR              "Physical Attributes"
#define MNT_STR_LOGICAL_ATTR               "Logical Attributes"
#define MNT_STR_DATA_BLOCK_SIZE            "dataBlockSize"

#define QMSGVERSION_MASK     0x07
#define QMSGENCODING_MASK    0x80

// Define macros to access QMsg header
#define QMSG_SET_ENDIAN(pMsg,x)   ((pMsg)->flags |= ((x) << 7))
#define QMSG_SET_VERSION(pMsg,x)  ((pMsg)->flags |= ((x) & 0x7))
#define QMSG_SET_FLAGS(pMsg,x)    ((pMsg)->flags = (x))
#define QMSG_SET_TRANS(pMsg,x)    ((pMsg)->transaction = (x))
#define QMSG_SET_MSGTYPE(pMsg,x)  ((pMsg)->type = (ULONG)(x))
#define QMSG_SET_SRCADDR(pMsg,x)  ((pMsg)->srcNode = (ULONG)((x))->node);\
			      ((pMsg)->srcBoard =(ULONG)((x))->board);\
			      ((pMsg)->srcProcessor = (ULONG)((x))->processor);\
			      ((pMsg)->srcComponent = (ULONG)((x))->component);\
			      ((pMsg)->srcInstance = (ULONG)((x))->instance)
#define QMSG_SET_DESTADDR(pMsg,lpDesc) ((pMsg)->destNode = (ULONG)(lpDesc)->node);\
			      ((pMsg)->destBoard = (ULONG)(lpDesc)->board);\
			      ((pMsg)->destProcessor = (ULONG)(lpDesc)->processor);\
			      ((pMsg)->destComponent = (ULONG)(lpDesc)->component);\
			      ((pMsg)->destInstance = (ULONG)(lpDesc)->instance)
#define QMSG_SET_MSGSIZE(pMsg,x)  ((pMsg)->msgsize = (ULONG)(x))

#define QMSG_GET_ENDIAN(pMsg,x)   (*(x) = (QByteOrder)((pMsg)->flags & QMSGENCODING_MASK ))
#define QMSG_GET_VERSION(pMsg,x)  (*(x) = (QMsgVersion)((pMsg)->flags & QMSGVERSION_MASK ))
#define QMSG_GET_FLAGS(pMsg,x)    (*(x) = ((pMsg)->flags))
#define QMSG_GET_TRANS(pMsg,x)    (*(x) =(QTrans)((pMsg)->transaction))
#define QMSG_GET_MSGTYPE(pMsg,x)  (*(x) =(pMsg->type))
#define QMSG_GET_SRCADDR(pMsg,lpDesc) ((lpDesc)->node = (USHORT)(pMsg)->srcNode);\
				      ((lpDesc)->board = (UCHAR)(pMsg)->srcBoard);\
				      ((lpDesc)->processor = (UCHAR)(pMsg)->srcProcessor);\
				      ((lpDesc)->component = (UCHAR)(pMsg)->srcComponent);\
				      ((lpDesc)->instance = (UCHAR)(pMsg)->srcInstance)
#define QMSG_GET_DESTADDR(pMsg,lpDesc) ((lpDesc)->node = (USHORT)(pMsg)->destNode);\
				      ((lpDesc)->board = (UCHAR)(pMsg)->destBoard);\
				      ((lpDesc)->processor = (UCHAR)(pMsg)->destProcessor);\
				      ((lpDesc)->component = (UCHAR)(pMsg)->destComponent);\
				      ((lpDesc)->instance = (UCHAR)(pMsg)->destInstance)
#define QMSG_GET_MSGSIZE(pMsg,x)  (*(x) = (ULONG)((pMsg)->msgsize))

// Processor Independent datatypes
typedef UInt24 QMsgField;

// new definition of datatype in kernel for using qMsgVarFieldGet/Put
enum QDatatype{
   QT_INT8, 
   QT_INT16,            
   QT_INT24,                    
   QT_INT32,                    
   QT_UINT8,            
   QT_UINT16,                   
   QT_UINT24,   
   QT_UINT32,    
   QT_FRAC16,                           
   QT_FRAC24,                   
   QT_CHAR,                     
   QT_CHAR_PACKED,  
   QT_MEMREF,                           
   QT_BUFREF,                           
   QT_STREAMREF,        
   QT_ATTR,       
   QT_COMPDESC,           
   QT_PARM,       
   QT_NULL=-1                   
};

#define QT_INT8_SIZE          1
#define QT_INT16_SIZE      2
#define QT_INT24_SIZE      3 
#define QT_INT32_SIZE      4
#define QT_UINT8_SIZE      1
#define QT_UINT16_SIZE     2 
#define QT_UINT24_SIZE     3 
#define QT_UINT32_SIZE     4
#define QT_FRAC16_SIZE     2 
#define QT_FRAC24_SIZE     3
#define QT_CHAR_SIZE          1
#define QT_CHAR_PACKED_SIZE     1
#define QT_MEMREF_SIZE     4
#define QT_BUFREF_SIZE     4
#define QT_STREAMREF_SIZE       11
#define QT_ATTR_SIZE          8
#define QT_COMPDESC_SIZE        6
#define QT_PARM_SIZE          4

#define QFIELDDEF_OFFSET         0      
#define QFIELDDEF_COUNT          11
#define QFIELDDEF_DATATYPE       19
#define QFIELDDEF_OFFSETMASK     0x0007ff  /* 11bits: large offset */
#define QFIELDDEF_COUNTMASK      0x07f800  /* 8 bits: 256 bytes */
#define QFIELDDEF_DATATYPEMASK   0xf80000  /* 5 bits: 32 types  */

#define QFieldDefSet(fieldDef, offset, count, type) \
{ \
	fieldDef = ((offset) << QFIELDDEF_OFFSET) | \
				  (((count)-1) << QFIELDDEF_COUNT) | \
				  ((type) << QFIELDDEF_DATATYPE); \
}

#define QFieldDef_GetOffset(fieldDef,value) \
(value = ((fieldDef & QFIELDDEF_OFFSETMASK) >> QFIELDDEF_OFFSET))
#define QFieldDef_GetCount(fieldDef,count) \
(count = ((fieldDef & QFIELDDEF_COUNTMASK) >> QFIELDDEF_COUNT) + 1)
#define QFieldDef_GetDatatype(fieldDef,value) \
(value = ((fieldDef & QFIELDDEF_DATATYPEMASK) >> QFIELDDEF_DATATYPE))
#define QFieldDef_PutOffset(fieldDef,value) \
(fieldDef |= ((value  << QFIELDDEF_OFFSET)& QFIELDDEF_OFFSETMASK))
#define QFieldDef_PutCount(fieldDef,count) \
(fieldDef |= (((count - 1)  << QFIELDDEF_COUNT)& QFIELDDEF_COUNTMASK))
#define QFieldDef_PutDatatype(fieldDef,value) \
(fieldDef |= ((value  << QFIELDDEF_DATATYPE)& QFIELDDEF_DATATYPEMASK))

//
// Contains all the processor specific code converting the
// basic datatypes to/from the local from/to global memory format
// used in the function qMsgFieldGet/Put
//
#define gtolUInt8(dest,src,destOffset,srcOffset) \
{ \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   destOffset += 1; \
}


#define gtolUInt16(dest,src,destOffset,srcOffset) \
{ \
   *((Uint8 *)(dest+destOffset+0)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   *((Uint8 *)(dest+destOffset+1)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   destOffset += 2; \
}


#define gtolUInt24(dest,src,destOffset,srcOffset) \
{ \
   *((Uint8 *)(dest+destOffset+0)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   *((Uint8 *)(dest+destOffset+1)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   *((Uint8 *)(dest+destOffset+2)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   *((Uint8 *)(dest+destOffset+3)) = 0; \
	destOffset += 4; \
}


#define gtolUInt32(dest,src,destOffset,srcOffset) \
{ \
   *((Uint8 *)(dest+destOffset+0)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   *((Uint8 *)(dest+destOffset+1)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   *((Uint8 *)(dest+destOffset+2)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   *((Uint8 *)(dest+destOffset+3)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   destOffset += 4; \
}


#define gtolInt8(dest,src,destOffset,srcOffset) \
	gtolUInt8(dest,src,destOffset,srcOffset) 


#define gtolInt16(dest,src,destOffset,srcOffset) \
	gtolUInt16(dest,src,destOffset,srcOffset) 


#define gtolInt24(dest,src,destOffset,srcOffset) \
{ \
	Uint8 tmp; \
   *((Uint8 *)(dest+destOffset+0)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
   *((Uint8 *)(dest+destOffset+1)) = *((Uint8 *)(src+srcOffset)); \
	srcOffset++; \
	tmp = *((Uint8 *)(src+srcOffset)); \
   *((Uint8 *)(dest+destOffset+2)) = tmp; \
	srcOffset++; \
   *((Uint8 *)(dest+destOffset+3)) = (tmp & 0x80)?(0xff):(0x00); \
	destOffset += 4; \
}


#define gtolInt32(dest,src,destOffset,srcOffset) \
	gtolUInt32(dest,src,destOffset,srcOffset) 


#define ltogUInt8(dest,src,destOffset,srcOffset) \
{ \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset)); \
   srcOffset += 1; \
	destOffset++; \
}


#define ltogUInt16(dest,src,destOffset,srcOffset) \
{ \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset+0)); \
	destOffset++; \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset+1)); \
	destOffset++; \
   srcOffset += 2; \
}


#define ltogUInt24(dest,src,destOffset,srcOffset) \
{ \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset+0)); \
	destOffset++; \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset+1)); \
	destOffset++; \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset+2)); \
	destOffset++; \
	srcOffset += 4; \
}


#define ltogUInt32(dest,src,destOffset,srcOffset) \
{ \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset+0)); \
	destOffset++; \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset+1)); \
	destOffset++; \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset+2)); \
	destOffset++; \
   *((Uint8 *)(dest+destOffset)) = *((Uint8 *)(src+srcOffset+3)); \
	destOffset++; \
   srcOffset += 4; \
}


#define ltogPtr(dest,src,destOffset,srcOffset) \
	ltogUInt32(dest,src,destOffset,srcOffset)

#define gtolPtr(dest,src,destOffset,srcOffset) \
	gtolUInt32(dest,src,destOffset,srcOffset)


#define ltogCompDesc(dest,src,destOffset,srcOffset) \
{ \
             ltogUInt16(dest,src,destOffset,srcOffset); \
             ltogUInt8(dest,src,destOffset,srcOffset); \
				 srcOffset += 1; \
             ltogUInt8(dest,src,destOffset,srcOffset); \
             ltogUInt8(dest,src,destOffset,srcOffset); \
             ltogUInt8(dest,src,destOffset,srcOffset); \
}

#define ltogStreamRef(dest,src,destOffset,srcOffset) \
{ \
             ltogUInt24(dest,src,destOffset,srcOffset); /* openMode */ \
             ltogPtr(dest,src,destOffset,srcOffset);    /* bHandle */  \
             ltogUInt16(dest,src,destOffset,srcOffset); /* streamId */      \
             ltogUInt16(dest,src,destOffset,srcOffset); /* pad */ \
}

#define gtolCompDesc(dest,src,destOffset,srcOffset) \
{ \
             gtolUInt16(dest,src,destOffset,srcOffset); \
             gtolUInt8(dest,src,destOffset,srcOffset); \
				 destOffset += 1; \
             gtolUInt8(dest,src,destOffset,srcOffset); \
             gtolUInt8(dest,src,destOffset,srcOffset); \
             gtolUInt8(dest,src,destOffset,srcOffset); \
}

#define gtolStreamRef(dest,src,destOffset,srcOffset) \
{ \
             gtolUInt24(dest,src,destOffset,srcOffset); \
             gtolPtr(dest,src,destOffset,srcOffset); \
             gtolUInt16(dest,src,destOffset,srcOffset); \
             gtolUInt16(dest,src,destOffset,srcOffset); \
}

#ifdef __cplusplus
extern "C" {
#endif

// Functional prototype for MMB
MNTAPI LPMMB WINAPI mntAllocateMMB(ULONG CommandSize, ULONG ReplyCount, ULONG ReplyMaxSize);
MNTAPI BOOL WINAPI mntClearMMB(LPMMB lpMMB);
MNTAPI LPMMB WINAPI mntCopyMMB(LPMMB lpMMB);

#if 0
  MNTAPI BOOL mntCreateDevice(HANDLE    hDevice, LPCSTR lpDeviceName, QCompDesc DeviceAddr,
	ULONG lDeviceType);
  MNTAPI BOOL mntDestroyDevice(HANDLE hDevice, LPCSTR lpDeviceName);
#endif 

MNTAPI BOOL WINAPI mntEnumMpathDevice(ULONG Mode, 
                               LPCSTR lpDeviceName,
                               PULONG lpDeviceNameSize,
                               PULONG lpDevStatus);
MNTAPI BOOL WINAPI mntEnumStrmDevice(ULONG Mode,
                              LPCSTR lpDeviceName,
                              PULONG lpDeviceNameSize,
                              PULONG lpDevStatus);
MNTAPI BOOL WINAPI mntFreeMMB(LPMMB lpMMB);
MNTAPI BOOL WINAPI mntGetBoardsByAttr(PQValueAttr lpAttr, 
                               ULONG MaxAttrs, 
                               PQBoardAttr lpBoardAttr,
                               PULONG lpTotalEntries,
                               PULONG lpBoardsFound);
MNTAPI BOOL WINAPI mntSendMessage(HANDLE hDevice, 
                           LPMMB lpMMB,
                           LPOVERLAPPED lpOverlapped);
MNTAPI BOOL WINAPI mntSendMessageWait(HANDLE hDevice,
                               ULONG nMsgType,
                               BOOL bEmptyMsg,
                               ULONG nPayloadSize,
                               PVOID lpPayload,
                               ULONG nExpectedReplies,
                               PQCompDesc lpDestAddr,
                               PULONG lpReplyType,
                               QMsgRef *lppReply);
MNTAPI BOOL WINAPI qMsgFieldGet(QMsg * pMessage, QMsgField fieldDef, void * pTarget);
MNTAPI BOOL WINAPI qMsgFieldPut(QMsg * pMessage, QMsgField fieldDef, void * pSource);
MNTAPI BOOL WINAPIV qMsgVarFieldPut(QMsg *pMessage, unsigned int count, unsigned int *pOffset,
	QMsgField fieldDef, void *pSource, ...);
MNTAPI BOOL WINAPIV qMsgVarFieldGet(QMsg *pMessage, unsigned int count, unsigned int *pOffset,
	QMsgField fieldDef, void *pTarget, ...);
MNTAPI BOOL WINAPI mntGetTLSmmb(LPMMB   *lppMMB, 
                         QMsgRef *lpCmdMsg,
                         QMsgRef *lpReplyMsg);
MNTAPI BOOL WINAPI mntGetMpathAddr(HANDLE hDevice, 
                            PQCompDesc lpSrcAddr, 
                            PQCompDesc lpDestAddr);
MNTAPI BOOL WINAPI mntRegisterAsyncMessages(HANDLE hDevice, 
		                               ULONG nCount,
		                               HANDLE *lpEvents,
                     	             LPMMB *lpMMBs);

#ifdef __cplusplus
}
#endif

#endif



