#include <ctype.h>   // isalpha, isdigit
#include <stdio.h>   // printf for debugging
#include <stdlib.h>  // atoi

#include "French_code.h"

French::French(void)
{
   InitialiseWordTable();
}

French::~French(void)
{
}

void French::InitialiseWordTable(void)
{
   wordTable[WB_CARDINAL + 0] = "zero";
   wordTable[WB_CARDINAL + 1] = "un";
   wordTable[WB_CARDINAL + 2] = "deux";
   wordTable[WB_CARDINAL + 3] = "trois";
   wordTable[WB_CARDINAL + 4] = "quatre";
   wordTable[WB_CARDINAL + 5] = "cinq";
   wordTable[WB_CARDINAL + 6] = "six";
   wordTable[WB_CARDINAL + 7] = "sept";
   wordTable[WB_CARDINAL + 8] = "huit";
   wordTable[WB_CARDINAL + 9] = "neuf";
   wordTable[WB_CARDINAL + 10] = "dix";
   wordTable[WB_CARDINAL + 11] = "onze";
   wordTable[WB_CARDINAL + 12] = "douze";
   wordTable[WB_CARDINAL + 13] = "treize";
   wordTable[WB_CARDINAL + 14] = "quatorze";
   wordTable[WB_CARDINAL + 15] = "quinze";
   wordTable[WB_CARDINAL + 16] = "seize";
   wordTable[WB_CARDINAL + 17] = "dix-sept";
   wordTable[WB_CARDINAL + 18] = "dix-huit";
   wordTable[WB_CARDINAL + 19] = "dix-neuf";
   wordTable[WB_CARDINAL + 20] = "vingt";
   wordTable[WB_CARDINAL + 30] = "trente";
   wordTable[WB_CARDINAL + 40] = "quarante";
   wordTable[WB_CARDINAL + 50] = "cinquante";
   wordTable[WB_CARDINAL + 60] = "soixante";
   wordTable[WB_CARDINAL + 80] = "quatre vingts";
   wordTable[WB_MONTH + 1] = "janvier";
   wordTable[WB_MONTH + 2] = "fvrier";
   wordTable[WB_MONTH + 3] = "mars";
   wordTable[WB_MONTH + 4] = "avril";
   wordTable[WB_MONTH + 5] = "mai";
   wordTable[WB_MONTH + 6] = "juin";
   wordTable[WB_MONTH + 7] = "juillet";
   wordTable[WB_MONTH + 8] = "aot";
   wordTable[WB_MONTH + 9] = "septembre";
   wordTable[WB_MONTH + 10] = "octobre";
   wordTable[WB_MONTH + 11] = "novembre";
   wordTable[WB_MONTH + 12] = "dcembre";
   wordTable[WB_ASCII + ' '] = "espace";
   wordTable[WB_ASCII + '!'] = "point d'exclamation";
   wordTable[WB_ASCII + '\"'] = "guillemets anglais";
   wordTable[WB_ASCII + '#'] = "dise";
   wordTable[WB_ASCII + '$'] = "dollar";
   wordTable[WB_ASCII + '%'] = "pour-cent";
   wordTable[WB_ASCII + '&'] = "esperluette";
   wordTable[WB_ASCII + '\''] = "apostrophe";
   wordTable[WB_ASCII + '('] = "parenthse gauche";
   wordTable[WB_ASCII + ')'] = "parenthse droigt";
   wordTable[WB_ASCII + '*'] = "astrisque";
   wordTable[WB_ASCII + '+'] = "signe plus";
   wordTable[WB_ASCII + ','] = "vergule";
   wordTable[WB_ASCII + '-'] = "trait d'union";
   wordTable[WB_ASCII + '.'] = "point";
   wordTable[WB_ASCII + '/'] = "barre oblique";
   wordTable[WB_ASCII + ':'] = "deux-points";
   wordTable[WB_ASCII + ';'] = "point-virgule";
   wordTable[WB_ASCII + '<'] = "signe infrieur";
   wordTable[WB_ASCII + '='] = "signe gal";
   wordTable[WB_ASCII + '>'] = "signe suprieur";
   wordTable[WB_ASCII + '?'] = "point d'interrogation";
   wordTable[WB_ASCII + '@'] = "arobas";
   wordTable[WB_ASCII + '['] = "crochet gauche";
   wordTable[WB_ASCII + '\\'] = "barre oblique inverse";
   wordTable[WB_ASCII + ']'] = "crochet droit";
   wordTable[WB_ASCII + '^'] = "caret";
   wordTable[WB_ASCII + '_'] = "soulign";
   wordTable[WB_ASCII + '{'] = "accolade gauche";
   wordTable[WB_ASCII + '|'] = "barre vertical";
   wordTable[WB_ASCII + '}'] = "accolade droit";
   wordTable[WB_ASCII + '~'] = "tilde";
   wordTable[WB_ASCII + ''] = "guillemet gauche";
   wordTable[WB_ASCII + ''] = "guillemet droit";
}

WordList French::DateWordList(string date, LanguageModule::SAY_FORMAT format)
{
   string year = date.substr(0, 4);
   string month = date.substr(5, 2);
   string day = date.substr(8, 2);
   WordList wordList;

   switch(format)
   {
      // cardinal-day month-name YYYY (except on first of month, which is ordinal-day month-name YYYY)
      case SAY_DATE:
      {
         if(atoi(day.c_str()) == 1)
         {
            wordList = "premier";
         }
         else
         {
            wordList += IntegerWordList(day, false);
         }
         wordList += wordTable[WB_MONTH + atoi(month.c_str())];
         wordList += IntegerWordList(year);
         break;
      }

      // DD de month-name
      case SAY_MONTHDAY:
      {
         if(atoi(day.c_str()) == 1)
         {
            wordList = "premier";
         }
         else
         {
            wordList += IntegerWordList(day, false);
         }
         wordList += wordTable[WB_MONTH + atoi(month.c_str())];
         break;
      }

      // month-name YYYY
      case SAY_YEARMONTH:
      {
         wordList = wordTable[WB_MONTH + atoi(month.c_str())];
         wordList += IntegerWordList(year);
         break;
      }
   }

   return(wordList);
}

WordList French::MoneyWordList(string money)
{
   WordList wordList;

   if(!Integer(money).empty())
   {
      wordList = IntegerWordList(Integer(money));
      wordList += "dollar";

      if(!Fraction(money).empty())
      {
         wordList += "et";
      }
   }

   if(!Fraction(money).empty())
   {
      wordList += IntegerWordList(Fraction(money));
      wordList += "cent";
   }

   return(wordList);
}

WordList French::NumberGroupWordList(string numberGroup, bool)
{
   WordList wordList;
   bool useTeen = false;
   string::iterator digit = numberGroup.begin();

   if(*digit == '+')
   {
      wordList += "plus";
      digit++;
   }
   else if(*digit == '-')
   {
      wordList += "moins";
      digit++;
   }

   for(; digit != numberGroup.end(); digit++)
   {
      switch(numberGroup.end() - digit)
      {
         // Hundreds column
         case 3:
         {
            if(*digit != '0')
            {
               wordList += wordTable[WB_CARDINAL + *digit - '0'];
               wordList += "cent";
            }

            break;
         }

         // Tens column
         case 2:
         {
            if(*digit != '0')
            {
               if((*digit == '1') || (*digit == '7') || (*digit == '9')) 
               {
                  useTeen = true;
               }
               else if(*(digit + 1) == '0')
               {
                  wordList += wordTable[WB_CARDINAL + (*digit - '0')*10];
                  return(wordList);
               }
               else
               {
                  wordList += wordTable[WB_CARDINAL + (*digit - '0')*10];
               }
            }
            break;
         }

         // Ones column
         case 1:
         {
            if(useTeen)
            {
               wordList += wordTable[WB_CARDINAL + 10 + *digit - '0'];
            }
            else if(*digit != '0')
            {
               wordList += wordTable[WB_CARDINAL + *digit - '0'];
            }
            break;
         }
      }
   }

   return(wordList);
}

WordList French::NumberGroupWordList(int index, bool)
{
   WordList wordList;

   switch(index)
   {
      case 1:
      {
         wordList = "mille";
         break;
      }

      case 2:
      {
         wordList = "million";
         break;
      }

      case 3:
      {
         wordList = "milliard";
         break;
      }

      case 4:
      {
         wordList = "billion";
         break;
      }
   }

   return(wordList);
}

WordList French::RealNumberWordList(string number)
{
   WordList wordList = IntegerWordList(Integer(number));

   if(!Fraction(number).empty())
   {
      string fraction = Fraction(number);

      wordList += "vergule";

      for(string::iterator digit = fraction.begin(); digit != fraction.end(); digit++)
      {
         wordList += wordTable[WB_CARDINAL + *digit - '0'];
      }
   }

   return(wordList);
}

WordList French::TimeWordList(string time, LanguageModule::SAY_FORMAT format)
{
   string hour = time.substr(0,2);
   string minute = time.substr(3,2);
   string second;
   int iHour = atoi(hour.c_str());
   WordList wordList;

   if(time.length() > 5)
   {
      second = time.substr(6,2);
   }

   if(iHour == 0)
   {
      wordList = "minuit";
   }
   else if(iHour == 12)
   {
      wordList = "midi";
   }
   else if((format == SAY_12HOUR) && (iHour > 12))
   {
      wordList = wordTable[WB_CARDINAL + iHour - 12];
   }
   else
   {
      wordList = IntegerWordList(hour);
      wordList += "heure";
   }

   if(atoi(minute.c_str()) != 0)
   {
      if((iHour == 0) || (iHour == 12))
      {
         wordList += "et";
      }

      wordList += IntegerWordList(minute);
   }

   if(!second.empty())
   {
      wordList += "et";
      wordList += IntegerWordList(second);
      wordList += "second";
   }

   if(format == SAY_12HOUR)
   {
      if((iHour > 0) && (iHour < 12))
      {
         wordList += "avant-midi";
      }
      else if(iHour > 12)
      {
         wordList += "aprs-midi";
      }
   }

   return(wordList);
}

LanguageModule* CreateLanguageModule(void)
{
   return(new French());
}

void ReleaseLanguageModule(LanguageModule* lang)
{
   delete (French*) lang;
}
