#include <stdarg.h>
#include "TIME.H"
#include "stdio.h"
#include "stdlib.h"
#include <ctype.h>
#include <string.h>

#include "StringSupport.h"

using std::string;
using std::vector;

static char formatTmp[1000];

const char *FormattedString( const char* fmt, ... )
{
    va_list arglist;
    va_start( arglist, fmt );

	_vsnprintf( formatTmp, sizeof( formatTmp ), fmt, arglist );

	va_end( arglist );

	return (const char *)&formatTmp[0];
}

void RemovePadding( string &input, char padding )
{
	if ( !input.length() )
	{
		return;
	}
	string tmp = "";
	unsigned int curChar = 0;
	for ( curChar = 0; ( ( curChar < strlen( input.c_str() ) ) && ( input.c_str()[curChar] == padding ) ); curChar++ );
	tmp = &input.c_str()[curChar];
	for ( curChar = strlen( tmp.c_str() ) - 1; ( tmp.c_str()[curChar] == padding ); curChar-- );
   tmp = tmp.substr( 0, curChar+1 );
	input = tmp.c_str();
}

int Tokenize( string input, const char *separator, vector<string> *tokens, bool removeSpaces, int maxTokens )
{
	tokens->clear();
	char *tracer = (char*)input.c_str();
	while ( ( tracer ) && ( strlen( tracer ) ) )
	{
		char *pos = strstr( tracer, separator );
		if ( ( maxTokens != -1 ) && ( (unsigned int)maxTokens == ( tokens->size() + 1 ) ) )
		{
			pos = NULL;
		}
		if ( pos )
		{
         string tmp = SubstringUpTo( tracer, separator );
			tokens->push_back( tmp );
			tracer = pos + strlen( separator );
		}
		else
		{
			tokens->push_back( tracer );
			tracer = NULL;
		}
	}
	if ( removeSpaces )
	{
		for ( unsigned int index = 0; index < tokens->size(); index++ )
		{
			string content = tokens->at( index );
			RemovePadding( content );
			tokens->at( index ) = content;
		}
	}
	return tokens->size();
}

void SearchAndReplace( string& source, const string& toReplace, const string& replaceWith )
{
	if ( ( replaceWith.length() ) && ( strstr( toReplace.c_str(), replaceWith.c_str() ) ) )
	{
		SearchAndReplace( source, toReplace, "\1" );
		SearchAndReplace( source, "\1", replaceWith );
	}
	else
	{
		size_t pos = string::npos;
		while ( ( pos = source.find( toReplace ) ) != std::string::npos )
      {
			source.replace( pos, toReplace.size(), replaceWith );
      }
	}
}

std::string SubstringUpTo( const std::string source, const std::string delimitorString )
{
   size_t pos = string::npos;
   if ( ( pos = source.find( delimitorString ) ) != std::string::npos )
   {
      return( source.substr( 0, pos ) );
   }
   else
   {
      return( "" );
   }
}

unsigned char NormalizeChar( int input, unsigned char normalizeFromChar, unsigned char normalizeToChar )
{
	while ( input > normalizeToChar )
	{
		input -= ( normalizeToChar - normalizeFromChar );
	}
	while ( input < normalizeFromChar )
	{
		input += ( normalizeToChar - normalizeFromChar );
	}
	return (unsigned char)input;
}

string GenerateUniqueString( unsigned int length, char useLower, char useUpper )
{
	static int seedCount;
	srand( (unsigned)time( NULL ) + seedCount );
	seedCount++;
	string dReturn = "";
	time_t dTime;
	time( &dTime );
	tm *dtmtime = localtime( &dTime );
	if ( length <= sizeof( tm ) )
	{
		for ( unsigned int index = 0; ( ( index < sizeof( tm ) ) && ( length > dReturn.length() ) ); index++ )
		{
			char dChar = (char)( *( (char*)(dtmtime) + index ) + rand() );
			dReturn += NormalizeChar( dChar, useLower, useUpper );
		}
	}
	return dReturn;
}

void LowercaseString( string& source )
{
	for( size_t index = 0; index < source.size(); index++ )
   {
		source[index] = (char)tolower( source[index] );
   }
}

