/* -------------------------------------------------------------------------
   ------------------------------------------------------------------------- */
#ifndef IV_MATH2_H
#define IV_MATH2_H

#include "..\TFServer\ivrinfo.h"

#if defined (__DLL__)
#define MATHAPI __declspec(dllexport)
#else
#define MATHAPI __declspec(dllimport)
#endif

enum MATH_FN { FN_LEN, FN_CAT, FN_SUBSTR, FN_ADD, FN_SUB, FN_MULT,
               FN_DIV, FN_MOD, FN_POW };

enum CMP_FN { FN_EQ, FN_NE, FN_LT, FN_GT, FN_LE, FN_GE, FN_NULL, FN_VALID, FN_LUHN };

enum FINCALC_FN { FIN_MTHLY_PYMT, FIN_MORT_AMT };

enum DATEINFO_FN { FN_WEEKDAY_SHORT, FN_WEEKDAY_LONG,
                   FN_MONTH_SHORT, FN_MONTH_LONG };

enum VAR_TYPE { VAR_DATE, VAR_TIME, VAR_DATETIME, VAR_STRING, VAR_INTEGER, VAR_FLOAT };

IV_STATUS VarMath(PIVRINFO pInfo, char*& value, const char* varB, const char* varC, const char* varD, MATH_FN fn);

IV_STATUS VarCmp(PIVRINFO pInfo, const char* varA, const char* varB, CMP_FN fn, bool &result, bool bSupressLog = false);

IV_STATUS VarValid(PIVRINFO pInfo, const char* testVar, VAR_TYPE dataType, bool& result);

bool VarValidTime(const char* timeStr);

/* -------------------------------------------------------------------------
   Name:        VarLUHN

   Purpose:     Determines if the value in a variable is a valid LUHN (mod-10 number)

   Notes: 		 Fails if the value is not a VAR_INTEGER
   ------------------------------------------------------------------------- */
IV_STATUS VarLUHN(PIVRINFO pInfo, char* testVar, bool& result);

IV_STATUS VarFinCalc(PIVRINFO pInfo, const char* pszResult, const char* pszAnnualIntRate,
   const char* pszMortgageAmt, const char* pszGrossIncome, FINCALC_FN fn);

IV_STATUS VarDateInfo(PIVRINFO pInfo, const char* varA, const char* varB, DATEINFO_FN fn, bool bUpperCase);

const char* VarTypeString(VAR_TYPE varType);
VAR_TYPE DetermineType(const char *s);

#undef MATHAPI

#endif
