#include "LoadLanguage.h"
#include "step_SetLanguage.h"

StepSetLanguage::StepSetLanguage(STEPREC& stepRecord) : Step(stepRecord)
{
   customModule = (bool) stepRecord.u1;
   languageModule = customModule ? stepRecord.s2.arr : stepRecord.s1.arr;
   promptsDirectory = stepRecord.s3.arr;
}

StepSetLanguage::~StepSetLanguage(void)
{
}

const char* StepSetLanguage::GetStepName(void) const
{
	return("Set Language");
}

IV_STATUS StepSetLanguage::Execute(PIVRINFO pInfo)
{
   IV_STATUS status;
   char* value;
   // Evaluate all parameters before exiting
   bool bParmsValid = true;
   string fullyPathedModule;
   string fullPromptsPath;

   if(Status(pInfo) != IVR_SUCCESS)
   {
      return(IVR_FAIL);
   }

   if(customModule)
   {
      if((value = pInfo->variables->ParseParameter("Language rules program", languageModule.c_str())) == NULL)
      {
         bParmsValid = false;
      }
      else
      {
         fullyPathedModule = value;
         delete[] value;

         value = pInfo->variables->FilePath(fullyPathedModule.c_str());
         fullyPathedModule = value;
         delete[] value;
      }
   }
   else
   {
   	fullyPathedModule = (string) pInfo->pszInstallationPath + (string) "Lang_" + languageModule + (string) ".dll";
   }

   // Empty prompts directory indicate that we should use default TeleFlow prompts
   // e.g. "English" -> "C:\Program Files\TeleFlow\Languages\English"
   if((value = pInfo->variables->ParseParameter("Location of prompt recordings", promptsDirectory.c_str(), "")) == NULL)
   {
      bParmsValid = false;
   }
   else
   {
      fullPromptsPath = value;
      delete[] value;

      if(fullPromptsPath.empty())
      {
         fullPromptsPath = (string) pInfo->pszInstallationPath + (string) "Languages\\" + languageModule;
      }
      else
      {
         value = pInfo->variables->FilePath(fullPromptsPath.c_str());
         fullPromptsPath = value;
         delete[] value;
      }
   }

   if(customModule && fullPromptsPath.empty())
   {
      pInfo->ivLog->Print("      ERROR: A prompts directory must be specified for a custom language module\n");
      bParmsValid = false;
   }

   if(!bParmsValid)
   {
      return(IVR_FATAL);
   }

	// Check against previosly loaded Language DLL
   // If they are the same, don't reload - TF Mar.6/04
   if(GetModuleHandle(fullyPathedModule.c_str()) == pInfo->languageLibrary)
   {
   	pInfo->ivLog->Print("      Language module '%s' already loaded\n", fullyPathedModule.c_str());
   }
   else
   {
	   if(!LoadLanguageModule(pInfo, fullyPathedModule.c_str()))
	   {
			pInfo->ivLog->Print("      Failed to load language module\n");
	      return(IVR_FAIL);
	   }
   }

   status = pInfo->variables->SetSystem("@PROMPT", fullPromptsPath.c_str()) ? IVR_SUCCESS : IVR_FAIL;

  	return(status);
}
