#include "..\BoardDLLs\brd_generic.h"
#include "step_SetVoIPMedia.h"

SetVoIPMedia::SetVoIPMedia(STEPREC& stepRecord) : Step(stepRecord)
{
   IPAddress = stepRecord.s1.arr;
   IPPort = stepRecord.s2.arr;
   prioritiseServerPayloads = (bool) stepRecord.u1;
   payloads = stepRecord.s3.arr;
}

SetVoIPMedia::~SetVoIPMedia(void)
{
}

const char* SetVoIPMedia::GetStepName(void) const
{
	return("Set VoIP Media");
}

IV_STATUS SetVoIPMedia::Execute(PIVRINFO pInfo)
{
   char* value;
   // Evaluate all parameters before exiting
   bool bParmsValid = true;
   string parsedIPAddress;
   string parsedIPPort;
   string parsedPayloads;
   string::size_type payloadBegin;
   string::size_type payloadEnd;

   if(Status(pInfo) != IVR_SUCCESS)
   {
      return(IVR_FAIL);
   }

   if((value = pInfo->variables->ParseParameter("Media IP Address", IPAddress.c_str())) == NULL)
   {
      bParmsValid = false;
   }
   else
   {
      parsedIPAddress = value;
      delete[] value;
   }

   if((value = pInfo->variables->ParseParameter("Media IP Port", IPPort.c_str())) == NULL)
   {
      bParmsValid = false;
   }
   else
   {
      parsedIPPort = value;
      delete[] value;
   }

   if((value = pInfo->variables->ParseParameter("Media Payloads", payloads.c_str())) == NULL)
   {
      bParmsValid = false;
   }
   else
   {
      parsedPayloads = value;
      delete[] value;
   }

   if(!bParmsValid)
   {
      return(IVR_FATAL);
   }

   pInfo->ivBoard->sdp.SetHostAddress(parsedIPAddress.c_str());
   pInfo->ivBoard->sdp.SetHostPort((unsigned short) atoi(parsedIPPort.c_str()));
   prioritiseServerPayloads ? pInfo->ivBoard->sdp.PrioritiseHostPayloads() : pInfo->ivBoard->sdp.PrioritisePeerPayloads();

   pInfo->ivBoard->sdp.ClearHostPayloads();

   for(payloadBegin = 0; (payloadEnd = parsedPayloads.find(' ', payloadBegin)) != string::npos; payloadBegin = payloadEnd + 1)
   {
      pInfo->ivBoard->sdp.AddHostPayload((SDPInfo::PAYLOAD) atoi(parsedPayloads.substr(payloadBegin, payloadEnd - payloadBegin).c_str()));
   }

   pInfo->ivBoard->sdp.AddHostPayload((SDPInfo::PAYLOAD) atoi(parsedPayloads.substr(payloadBegin).c_str()));

   return(IVR_SUCCESS);
}
