#include <stdlib.h>             // Needed for "atoi".
#include "step_getdigits.h"
#include "..\BoardDLLs\brd_generic.h"

StepGetDigits::StepGetDigits(STEPREC& stepRecord) : Step(stepRecord)
{
   varNm = stepRecord.s1.arr;
   timeout = stepRecord.s2.arr;
   maxLen  = stepRecord.s3.arr;
   TTOkay = stepRecord.s4.arr;
   TTTerm = stepRecord.s5.arr;
}

StepGetDigits::~StepGetDigits(void)
{
}

const char* StepGetDigits::GetStepName(void) const
{
	return("Get TT String");
}

IV_STATUS StepGetDigits::Execute(PIVRINFO pInfo)
{
   IV_STATUS   status;
   int         iTimeout;     // Timeout between key presses.
   int         iMaxLen;      // Number of digits to collect.
   char* value;
   // Evaluate all parameters before exiting
   bool bParmsValid = true;
   string parsedTTOkay;       // Digits that are valid.
   string parsedTTTerm;       // Digits that terminate digit collection.
   char* digits;       // Digit buffer returned from GetDigits

   if(Status(pInfo) != IVR_SUCCESS)
   {
      return(IVR_FAIL);
   }

	if(PortRequired(pInfo) != IVR_SUCCESS)
   {
      return(IVR_FATAL);
   }

   if((value = pInfo->variables->ParseParameter("TIMEOUT", timeout.c_str(), "@TIMEOUT")) == NULL)
   {
      bParmsValid = false;
   }
   else
   {
      iTimeout = atoi(value);
      delete[] value;

      if(iTimeout < 0)
      {
		   pInfo->ivLog->Print("      ERROR: TIMEOUT '%s' must be >= 0\n", timeout.c_str());
         bParmsValid = false;
      }
   }

   if((value = pInfo->variables->ParseParameter("Maximum TTs", maxLen.c_str(),
      "-1", "Empty Maximum TTs defaults to none")) == NULL)
   {
      bParmsValid = false;
   }
   else
   {
      iMaxLen = atoi(value);
      delete[] value;

      if((iMaxLen <= 0) && (iMaxLen != INFINITE))
      {
         pInfo->ivLog->Print("      ERROR: Maximum Touch Tones '%s' must be at least 1\n", maxLen.c_str());
         bParmsValid = false;
      }
   }

   if((value = pInfo->variables->ParseParameter("Allowable TTs", TTOkay.c_str())) == NULL)
   {
      bParmsValid = false;
   }
   else
   {
      parsedTTOkay = value;
      delete[] value;
   }

   if((value = pInfo->variables->ParseParameter("Termination TTs", TTTerm.c_str(), "")) == NULL)
   {
      bParmsValid = false;
   }
   else
   {
      parsedTTTerm = value;
      delete[] value;
   }

   // Blank out variable to receive Touch Tones.
   if(!pInfo->variables->Set(varNm.c_str(), ""))
   {
      pInfo->ivLog->Print("      ERROR: Failed to set Touch Tones variable '%s'\n", varNm.c_str());
      return(IVR_FATAL);
   }

   if(!bParmsValid)
   {
      return(IVR_FATAL);
   }

   status = pInfo->ivBoard->GetDigits(iMaxLen, digits, iTimeout, parsedTTOkay.c_str(), parsedTTTerm.c_str());

   pInfo->ivLog->Print("      Got: '%s'\n", digits);

   if(status == IVR_SUCCESS)
   {
      if(!pInfo->variables->Set(varNm.c_str(), digits))
      {
         pInfo->ivLog->Print("      ERROR: Failed to set Touch Tones variable '%s'\n", varNm.c_str());
      }
   }

   delete[] digits;

   return(status);
}
