#include "step_varmath.h"

StepVarMath::StepVarMath(STEPREC& stepRecord) : Step(stepRecord)
{
   varA = stepRecord.s1.arr;
   varB = stepRecord.s2.arr;
   varC = stepRecord.s3.arr;
   varD = stepRecord.s4.arr;
   switch(stepRecord.u1)
   {
      case 1: iFn = FN_ADD;     break;
      case 2: iFn = FN_SUB;     break;
      case 3: iFn = FN_MULT;    break;
      case 4: iFn = FN_DIV;     break;
      case 5: iFn = FN_MOD;     break;
      case 6: iFn = FN_SUBSTR;  break;
      case 7: iFn = FN_LEN;     break;
      case 8: iFn = FN_CAT;     break;
      case 9: iFn = FN_POW;     break;
      default:
      {
//@@@ Should be invalid math function type      
      }
   }
}

StepVarMath::~StepVarMath(void)
{
}

const char* StepVarMath::GetStepName(void) const
{
	return("Math");
}

IV_STATUS StepVarMath::Execute (PIVRINFO pInfo)
{
   // Evaluate all parameters before exiting
   bool bParmsValid = true;
   char* valueA;
   char* valueB;
   char* valueC;
   char* valueD = NULL;
   IV_STATUS status;

   if(Status(pInfo) != IVR_SUCCESS)
   {
      return(IVR_FAIL);
   }

   if((valueB = pInfo->variables->ParseParameter("Base value", varB.c_str(), "")) == NULL)
   {
      bParmsValid = false;
   }

   if((valueC = pInfo->variables->ParseParameter("Modifying value", varC.c_str(), "")) == NULL)
   {
      bParmsValid = false;
   }

   if(iFn == FN_SUBSTR)
   {
      if((valueD = pInfo->variables->ParseParameter("Number of characters to copy", varD.c_str(), "")) == NULL)
      {
         bParmsValid = false;
      }
   }

   if(!bParmsValid)
   {
      delete[] valueB;
      delete[] valueC;
      delete[] valueD;
      return(IVR_FATAL);
   }

   switch (iFn) {


      case FN_LEN:
      {
         // pInfo->ivLog->Debug ('v', "         %s = LENGTH (%s)\n", varA, varB);
         pInfo->ivLog->Print ("         %s = LENGTH (%s)\n", varA.c_str(), varB.c_str());
         pInfo->ivLog->Print ("         %s = LENGTH (%s)\n", varA.c_str(), valueB);
         break;
      }

      case FN_CAT:
      {
         // pInfo->ivLog->Debug ('v', "         %s = %s CAT %s\n", varA, varB, varC);
         pInfo->ivLog->Print ("         %s = %s CAT %s\n", varA.c_str(), varB.c_str(), varC.c_str());
         pInfo->ivLog->Print ("         %s = %s CAT %s\n", varA.c_str(), valueB, valueC);
         break;
      }

      case FN_SUBSTR:
      {
         // pInfo->ivLog->Debug ('v', "         %s = substr (%s, %s, %s)\n",
         //              varA, varB, varC, varD);
         pInfo->ivLog->Print ("         %s = substr (%s, %s, %s)\n", varA.c_str(), varB.c_str(), varC.c_str(), varD.c_str());
         pInfo->ivLog->Print ("         %s = substr (%s, %s, %s)\n", varA.c_str(), valueB, valueC, valueD);
         break;
      }

      case FN_ADD:
      {
         pInfo->ivLog->Print ("         %s = %s + %s\n", varA.c_str(), varB.c_str(), varC.c_str());
         pInfo->ivLog->Print ("         %s = (%s):%s + (%s):%s\n", varA.c_str(), VarTypeString(DetermineType(valueB)), valueB, VarTypeString(DetermineType(valueC)), valueC);
         break;
      }

      case FN_SUB:
      {
         // pInfo->ivLog->Debug ('v', "         %s = %s - %s\n", varA, varB, varC);
         pInfo->ivLog->Print ("         %s = %s - %s\n", varA.c_str(), varB.c_str(), varC.c_str());
         pInfo->ivLog->Print ("         %s = (%s):%s - (%s):%s\n", varA.c_str(), VarTypeString(DetermineType(valueB)), valueB, VarTypeString(DetermineType(valueC)), valueC);
         break;
      }

      case FN_MULT:
      {
         // pInfo->ivLog->Debug ('v', "         %s = %s * %s\n", varA, varB, varC);
         pInfo->ivLog->Print ("         %s = %s * %s\n", varA.c_str(), varB.c_str(), varC.c_str());
         pInfo->ivLog->Print ("         %s = (%s):%s * (%s):%s\n", varA.c_str(), VarTypeString(DetermineType(valueB)), valueB, VarTypeString(DetermineType(valueC)), valueC);
         break;
      }

      case FN_DIV:
      {
         // pInfo->ivLog->Debug ('v', "         %s = %s / %s\n", varA, varB, varC);
         pInfo->ivLog->Print ("         %s = %s / %s\n", varA.c_str(), varB.c_str(), varC.c_str());
         pInfo->ivLog->Print ("         %s = (%s):%s / (%s):%s\n", varA.c_str(), VarTypeString(DetermineType(valueB)), valueB, VarTypeString(DetermineType(valueC)), valueC);
         break;
      }

      case FN_MOD:
      {
         // pInfo->ivLog->Debug ('v', "         %s = %s % %s\n", varA, varB, varC);
         pInfo->ivLog->Print ("         %s = %s %s %s\n", varA.c_str(), varB.c_str(), "%", varC.c_str());
         pInfo->ivLog->Print ("         %s = (%s):%s %s (%s):%s\n", varA.c_str(), VarTypeString(DetermineType(valueB)), valueB, "%", VarTypeString(DetermineType(valueC)), valueC);
         break;
      }

      case FN_POW:
      {
         // pInfo->ivLog->Debug ('v', "         %s = %s % %s\n", varA, varB, varC);
         pInfo->ivLog->Print ("         %s = %s to the power of %s\n", varA.c_str(), varB.c_str(), varC.c_str());
         pInfo->ivLog->Print ("         %s = (%s):%s to the power of (%s):%s\n", varA.c_str(), VarTypeString(DetermineType(valueB)), valueB, VarTypeString(DetermineType(valueC)), valueC);

         break;
      }

   }

   status = VarMath(pInfo, valueA, valueB, valueC, valueD, iFn);

   if(status == IVR_SUCCESS)
   {
      status = pInfo->variables->Set(varA.c_str(), valueA) ? IVR_SUCCESS : IVR_FATAL;
   }

   delete[] valueA;
   delete[] valueB;
   delete[] valueC;
   delete[] valueD;

   return(status);
}
