#include <vcl.h>
#include <stdio.h>
#include <string.h>
#include <algorithm>
using std::min;
#pragma hdrstop

#include "mon_main.h"
#include "dlg_host.h"
//---------------------------------------------------------------------------
#pragma package(smart_init)
#pragma resource "*.dfm"
TFormConnect *FormConnect;

/* -------------------------------------------------------------------------
   Name:        TFormConnect::TFormConnect
   ------------------------------------------------------------------------- */
__fastcall TFormConnect::TFormConnect(TComponent* Owner)
    : TForm(Owner)
    , iHosts(0)
    , bUpdatingList(false)
{
   memset (&hosts, 0, sizeof(hosts));

   // Load settings from the registry
   ReadRegistry();
   if(iHosts == 0)
   {
      strcpy (hosts[0].szName, "localhost");
      iHosts = 1;
   }
   for (int ii = 0; ii < iHosts; ii++)
      cboxHost->Items->Add (hosts[ii].szName);
   cboxHost->ItemIndex = 0;

	CheckBoxAutoConnect->Checked = FormMon->bAutoConnect;
}
/*TFormConnect::TFormConnect*/

/* -------------------------------------------------------------------------
   Name:        TFormConnect::~TFormConnect
   ------------------------------------------------------------------------- */
__fastcall TFormConnect::~TFormConnect()
{
}
/*TFormConnect::~TFormConnect*/

/* -------------------------------------------------------------------------
   Name:        TFormConnect::ReadRegistry

   Purpose:     Reads in the registry values into application memory.

   Notes:       - When a new field is added to the form, it won't exist in
                  the registry.  Don't stop loading registry settings if one
                  value is missing.
   ------------------------------------------------------------------------- */
void __fastcall TFormConnect::ReadRegistry()
{
	// iHosts should be 0
   LONG  ret;
   HKEY  hkey;
   DWORD dwLen;
   DWORD dwType;
   char  szKey[26];  // Capable of holding "Host %d" for up to 64-bit int ii
   char *pszValue;

   try
   {
   	ret = RegOpenKeyEx(HKEY_LOCAL_MACHINE, TFMONITOR_REG_KEY, 0, KEY_READ, &hkey);

      if(ret != ERROR_SUCCESS)
      {
      	return;
      }

      for(int ii = 0; ii < HOST_LIST_SIZE; ii++)
      {
      	sprintf(szKey, "Host %d", ii);

         // Get length of string
         ret = RegQueryValueEx(hkey, szKey, NULL, &dwType, NULL, &dwLen);

         if(ret == ERROR_SUCCESS)
         {  // Length can be at most HOST_NAME_MAX_LENGTH
            dwLen = min(dwLen, (unsigned long) HOST_NAME_MAX_LENGTH);

            // Copy the string
            ret = RegQueryValueEx(hkey, szKey, NULL, &dwType, hosts[iHosts++].szName, &dwLen);

            // Don't count it if it screws up
            if(ret != ERROR_SUCCESS)
            {
            	iHosts--;
            }
         }
         // Default value if registry key doesn't exists or can't be read
         else
         {
         	strcpy(hosts[iHosts].szName, "");
         }
      }

      RegCloseKey(hkey);
   }

   catch(Exception &e)
   {  Application->MessageBox(e.Message.c_str(), "ReadRegistry", MB_OK | MB_ICONERROR);
   }
}
/*TFormConnect::ReadRegistry*/

/* -------------------------------------------------------------------------
   Name:        TFormConnect::WriteRegistry
   ------------------------------------------------------------------------- */
void __fastcall TFormConnect::WriteRegistry()
{  LONG  ret;
   HKEY  hkey;
   DWORD dwDisposition;
   DWORD dwLen;
   char  szKey[80];
   unsigned char  szValue[255];

   try
   {  ret = RegCreateKeyEx (
         HKEY_LOCAL_MACHINE,      // Handle of an open key.
         TFMONITOR_REG_KEY,              // Address of subkey name.
         0,                       // Reserved.
         0,                       // Address of class string.
         REG_OPTION_NON_VOLATILE, // Special options flag.
         KEY_WRITE,               // Desired security access.
         0,                       // Address of key security structure.
         &hkey,                   // Address of buffer for opened handle.
         &dwDisposition);         // Address of disposition value buffer.

      if(ret != ERROR_SUCCESS)
      {  Application->MessageBox("Failed to create registry key.", "Registry Save Failed", MB_ICONERROR | MB_OK);
      }
      else
      {
      	FormMon->bAutoConnect = CheckBoxAutoConnect->Checked;

         for(int ii = 0; ii < iHosts; ii++)
         {  sprintf(szKey, "Host %d", ii);
            sprintf((char*)szValue, "%s", hosts[ii].szName);
            dwLen = strlen((char*)szValue) + 1;
            ret &= RegSetValueEx(
               hkey,              // Handle of key to set value for.
               szKey,             // Address of value to set.
               0,                 // Reserved.
               REG_SZ,            // Flag for value type.
               szValue,           // Address of value data.
               dwLen);            // Size of value data.
         }

         if(ret != ERROR_SUCCESS)
         {  Application->MessageBox("Failed to write host entry.", "Registry Save Failed", MB_ICONERROR | MB_OK);
         }

         RegCloseKey(hkey);
      }
   }

   catch(Exception &e)
   {  Application->MessageBox(e.Message.c_str(), "ReadRegistry", MB_OK | MB_ICONERROR);
   }
}
/*TFormConnect::WriteRegistry*/

/* -------------------------------------------------------------------------
   Name:        TFormConnect::SwapHosts
   ------------------------------------------------------------------------- */
void __fastcall TFormConnect::SwapHosts (int ii, int jj)
{  char* szName = new char[strlen(hosts[ii].szName) + 1];

   strcpy(szName, hosts[ii].szName);
   strcpy(hosts[ii].szName, hosts[jj].szName);
   strcpy(hosts[jj].szName, szName);
   delete szName;
}
/*TFormConnect::SwapHosts*/

/* -------------------------------------------------------------------------
   Name:        TFormConnect::btnOkayClick

   Purpose:     When the user selects a host, move it to the top of the
                list.  If the user adds a new host, add it to the top of the
                list throwing away the last entry if no more room exists.
   ------------------------------------------------------------------------- */
void __fastcall TFormConnect::btnOkayClick(TObject *Sender)
{
	AddCurrentHostToHistory();
  	FormMon->bAutoConnect = CheckBoxAutoConnect->Checked;
}
/*TFormConnect::btnOkayClick*/
//---------------------------------------------------------------------------
void __fastcall TFormConnect::cboxHostChange(TObject *Sender)
{  // Activate AutoConnect checkbox if Host combobox is not blank
   CheckBoxAutoConnect->Enabled = strcmp(cboxHost->Text.c_str(), "");
}
//---------------------------------------------------------------------------
void __fastcall TFormConnect::btnCancelClick(TObject *Sender)
{
	// Reload settings
   cboxHost->ItemIndex = 0;
  	CheckBoxAutoConnect->Checked = FormMon->bAutoConnect;
}
//---------------------------------------------------------------------------

void __fastcall TFormConnect::AddCurrentHostToHistory(void)
{
	int ii = cboxHost->ItemIndex;
   bool itemFound = (ii != -1);

   // Selection typed in
   if(ii == -1)
   {
   	// Search for previously used host (assignment intentional)
      for(ii = 0; (ii < iHosts) || ((itemFound = !stricmp(hosts[ii].szName, cboxHost->Text.c_str())) != 0); ii++);

      // Decrement back to found item index
      if(itemFound)
      {
      	ii--;
      }

      // Add new selection
      if(!itemFound && (iHosts != HOST_LIST_SIZE))
      {
      	strcpy(hosts[ii].szName, cboxHost->Text.c_str());
         cboxHost->Items->Add(cboxHost->Text);
         iHosts++;
      }

      // Replace the bottom section
      if(!itemFound && (iHosts == HOST_LIST_SIZE))
      {
      	ii--;
         strcpy(hosts[ii].szName, cboxHost->Text.c_str());
         cboxHost->Items->Strings[ii] = cboxHost->Text;
      }
   }

   // Bubble up selection
   for (; ii > 0; ii--)
   {
   	SwapHosts(ii, ii - 1);
      AnsiString asTemp = cboxHost->Items->Strings[ii];
      cboxHost->Items->Strings[ii] = cboxHost->Items->Strings[ii - 1];
      cboxHost->Items->Strings[ii - 1] = asTemp;
   }

   // Initiate cboxHost choice for next time
   cboxHost->ItemIndex = 0;

   // Save settings
   WriteRegistry();
}
