/* -------------------------------------------------------------------------
   File:        GUI_LOG.H

                Copyright (c) 1997 - 2001 enGenic.
                All rights reserved.
   ------------------------------------------------------------------------- */
#ifndef GUI_LOG_H
#define GUI_LOG_H

#include <winsock2.h>
#include <windows.h>
#include <vector>
using std::vector;
#include <string>
using std::string;

#include "..\escutil\criticalsection.h"

#include "log.h"

typedef void (*PrintFnPtr)(void*, const string&, bool);

class GUILog : public Log
{
   public:

      GUILog(int maxFileSize, unsigned int maxLines = 100, unsigned int maxLineSize = 100);
      virtual ~GUILog(void);

      int GetLines(char* outLines);
      int GetLines(char** outLines, unsigned lineCount);
      int GetMaxLines(void);
      int GetMaxLineSize(void);
      bool WriteToFile(const char* pszFileNm, bool bAppend = false, bool bUnbuffered = false);
      bool SaveLogToFile(const char* pszFileNm, bool bAppend = true, bool bUnbuffered = false);
      void Reset(void);

      virtual void PrintLine(const string& asLine, bool bEOL);

      void SetPrintFnPtr(PrintFnPtr fn, void* param);

   private:

      unsigned int   iMaxLines;
      unsigned int   iMaxLineSize;
      unsigned int   iFirstLine;
      unsigned int   iLastLine;
      vector<string> lines;
      Mutex myMutex;

      PrintFnPtr     pFnPrint;
      void* pFnPrintParam;

      // Prevent compiler from creating default constructor, default copy
      // constructor, and assignment operator.
      GUILog(void);
      GUILog(const GUILog&);
      GUILog& operator=(const GUILog&);
};

#endif
