#ifndef CRITICALSECTION_H
#define CRITICALSECTION_H

#include <winsock2.h>
#include <windows.h>

#if defined (__DLL__)
#define CRITICALSECTIONAPI __declspec(dllexport)
#else
#define CRITICALSECTIONAPI __declspec(dllimport)
#endif

class CRITICALSECTIONAPI CriticalSection
{
   public:

      // Creates a critical section that will ensure single thread processing when
      // Enter is used
      CriticalSection(void);

      // Automatically Leaves critical section enough times to release Enters
      ~CriticalSection(void);

      // Ensures single thread processing until Leave or CriticalSection falls
      // out of scope
      // A CriticalSection may be Entered multiple times and ensures single thread
      // processing until an equal number of Leaves are called
      void Enter(void);

      // Releases one Enter and ensures single thread processing until all Enters
      // have been released
      void Leave(void);

   private:

      CRITICAL_SECTION cs;
      int count;
};

class CRITICALSECTIONAPI Mutex
{
   public:

      // Creates a mutex that will ensure single thread access to a resource
      Mutex(void);

      // Automatically Releases mutex enough times to release Gets
      ~Mutex(void);

      // Blocks until a mutex is released unless it is already held by the same thread
      void Get(void);

      // Releases one Get and ensures single thread access until all Gets have been released
      void Release(void);

   private:

      HANDLE mhandle;
      int count;
};

#undef CRITICALSECTIONAPI

#endif
